summaryrefslogtreecommitdiff
path: root/sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx')
-rwxr-xr-xsd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx24
1 files changed, 12 insertions, 12 deletions
diff --git a/sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx b/sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx
index 9b7b1f5ec2d3..ae6f2dceb277 100755
--- a/sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx
+++ b/sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx
@@ -87,25 +87,25 @@ public:
const AcceptDropEvent& rEvt,
DropTargetHelper& rTargetHelper,
::sd::Window* pTargetWindow = NULL,
- USHORT nPage = SDRPAGE_NOTFOUND,
- USHORT nLayer = SDRPAGE_NOTFOUND );
+ sal_uInt16 nPage = SDRPAGE_NOTFOUND,
+ sal_uInt16 nLayer = SDRPAGE_NOTFOUND );
sal_Int8 ExecuteDrop (
const ExecuteDropEvent& rEvt,
DropTargetHelper& rTargetHelper,
::sd::Window* pTargetWindow = NULL,
- USHORT nPage = SDRPAGE_NOTFOUND,
- USHORT nLayer = SDRPAGE_NOTFOUND);
+ sal_uInt16 nPage = SDRPAGE_NOTFOUND,
+ sal_uInt16 nLayer = SDRPAGE_NOTFOUND);
void Abort (void);
protected:
- virtual USHORT DetermineInsertPosition (
+ virtual sal_uInt16 DetermineInsertPosition (
const SdTransferable& rTransferable);
- virtual USHORT InsertSlides (
+ virtual sal_uInt16 InsertSlides (
const SdTransferable& rTransferable,
- USHORT nInsertPosition);
+ sal_uInt16 nInsertPosition);
private:
SlideSorter& mrSlideSorter;
@@ -126,7 +126,7 @@ private:
/** When pages are moved or copied then the selection of the slide
sorter has to be updated. This flag is used to remember whether the
- selection has to be updated or can stay as it is (FALSE).
+ selection has to be updated or can stay as it is (sal_False).
*/
bool mbUpdateSelectionPending;
@@ -137,7 +137,7 @@ private:
::boost::scoped_ptr<UndoContext> mpUndoContext;
::boost::scoped_ptr<SelectionObserver::Context> mpSelectionObserverContext;
- ULONG mnDragFinishedUserEventId;
+ sal_uLong mnDragFinishedUserEventId;
void CreateSlideTransferable (
::Window* pWindow,
@@ -179,7 +179,7 @@ private:
*/
void SelectPageRange (sal_Int32 nFirstIndex, sal_Int32 nPageCount);
/** Return <TRUE/> when the current transferable in the current state of
the slidesorter is acceptable to be pasted. For this the
transferable has to
a) exist,
@@ -218,8 +218,8 @@ private:
const void* pDropEvent ,
DropTargetHelper& rTargetHelper,
::sd::Window* pTargetWindow,
- USHORT nPage,
- USHORT nLayer);
+ sal_uInt16 nPage,
+ sal_uInt16 nLayer);
/** Asynchronous part of DragFinished. The argument is the sal_Int8
nDropAction, disguised as void*.
@@ -179,7 +179,7 @@ private:
*/
void SelectPageRange (sal_Int32 nFirstIndex, sal_Int32 nPageCount);
- /** Return <TRUE/> when the current transferable in the current state of
+ /** Return <sal_True/> when the current transferable in the current state of
the slidesorter is acceptable to be pasted. For this the
transferable has to